@@ -1,3 +1,5 @@
+import logging
+
 from django.contrib.auth.models import User
 from django.http import HttpResponseRedirect, Http404, HttpResponse
 from django.shortcuts import render_to_response, get_object_or_404
@@ -5,9 +7,11 @@ from django.template import RequestContext
 from django.conf import settings
 from django.template.loader import get_template
 from django.template.base import Template
+
 from .utils import get_email_directories
 from .parse_util import recursive_block_replace
 
+logger = logging.getLogger('templated_emails')
 
 def index(request, template_name="templated_emails/index.html"):
     if not request.user.is_superuser:
@@ -35,19 +39,19 @@ def view(request, path, template_name="templated_emails/view.html"):
             template = get_template("emails%s/email.html"%path)
             rendered_html = recursive_block_replace(template, {})
         except:
-            pass # there might be no html
+            logger.exception("Error rendering templated email email.html")
 
         try:
             template = get_template("emails%s/email.txt"%path)
             rendered_text = recursive_block_replace(template, {})
         except:
-            pass # there might be no text file
+            logger.exception("Error rendering templated email email.txt")
 
         try:
             template = get_template("emails%s/short.txt"%path)
             rendered_subject = recursive_block_replace(template, {})
         except:
-            pass # there might be no html
+            logger.exception("Error rendering templated email short.txt")
 
         return render_to_response(template_name, {
             "rendered_subject": rendered_subject,
